
AT_WARRINGTON = '@warrington.ufl.edu'
ASSISTANT_PROF = 'Assistant Professor'
ASSOCIATE_PROF_OF_FINANCE = 'Associate Professor of Finance'

# Keys to reference authors
ANDY = 'andy'
NIMAL = 'nimal'
NITISH = 'nitish'
SUGATA = 'sugata'
CORBIN = 'corbin'
JIMMY = 'jimmy'
BAOLIAN = 'baolian'
